<template>
  <a-card
    title="设备故障类型统计"
    :bordered="true"
  >
    <!-- 查询区域 -->
    <div class="table-page-search-wrapper">
      <a-form
        layout="inline"
        @keyup.enter.native="searchQuery"
      >
        <a-row :gutter="24">
          <a-col
            :md="6"
            :sm="8"
          >
            <a-form-item label="统一编码">
              <a-input
                placeholder="请输入统一编码"
                v-model="queryParam.equipmentNum"
              ></a-input>
            </a-form-item>
          </a-col>
          <a-col
            :md="6"
            :sm="8"
          >
            <a-form-item label="使用部门">
              <j-dict-select-tag
                allow-clear
                placeholder='请选择使用部门'
                :triggerChange='true'
                dictCode="sys_depart,depart_name,id,del_flag!='1'"
                v-model='queryParam.useId'
              />
            </a-form-item>
          </a-col>
          <a-col
            :md="6"
            :sm="8"
          >
            <a-form-item label="维修时间">
              <a-range-picker
                style="width: 100%;"
                format="YYYY-MM-DD HH:mm:ss"
                v-model="faultTime"
                @change="timeChange"
              />
            </a-form-item>
          </a-col>
          <a-col
            :md="6"
            :sm="8"
          >
            <span
              style="float: left;overflow: hidden;"
              class="table-page-search-submitButtons"
            >
              <a-button
                type="primary"
                @click="searchQuery"
                icon="search"
              >查询</a-button>
              <a-button
                type="primary"
                @click="searchReset"
                icon="reload"
                style="margin-left: 8px"
              >重置</a-button>
            </span>
          </a-col>
        </a-row>
      </a-form>
    </div>
    <!-- 查询区域-END -->

    <a-row>
      <a-col
        :sm="24"
        :md="24"
        :xl="12"
        :style="{ marginBottom: '15px' }"
      >
        <a-card
          :loading="loading"
          :bordered="true"
          title=""
        >
          <pie :dataSource="defectInfo"></pie>
        </a-card>

      </a-col>
      <a-col
        :sm="24"
        :md="24"
        :xl="12"
        :style="{ marginBottom: '15px' }"
      >
        <a-card
          :loading="loading"
          :bordered="true"
          title=""
        >
          <bar
            title=""
            :dataSource="barData"
          />
        </a-card>
      </a-col>
    </a-row>

  </a-card>
</template>

<script>

import '@/assets/less/TableExpand.less'
import { mixinDevice } from '@/utils/mixin'
import { JeecgListMixin } from '@/mixins/JeecgListMixin'
import { getAction, deleteAction, postAction } from '@/api/manage'
import Pie from '@/components/chart/Pie'
import Bar from '@/components/chart/Bar'
import moment from 'moment'

export default {
  name: 'FaultCauseChart',
  mixins: [JeecgListMixin, mixinDevice],
  components: {
    Pie,
    Bar
  },
  data() {
    return {
      description: 'FaultCauseChart',
      // barData: [{ x: '设备故障', y: 5 }, { x: '其他', y: 8 }],
      barData: [],
      defectInfo: [],
      url: {
        list: "/eam/repairOrder/getFaultCausePie",
        list2: "/eam/repairOrder/getFaultCauseBar",
      },
      // 表头
      faultTime: [],
      dictOptions: {},
      superFieldList: [],
      queryParam: {}
    }
  },
  created() {
    this.loadData2(1);
  },
  methods: {

    timeChange() {
      this.queryParam.faultStartTime = moment(this.faultTime[0]).format("YYYY-MM-DD HH:mm:ss")
      this.queryParam.faultEndTime = moment(this.faultTime[1]).format("YYYY-MM-DD HH:mm:ss")
    },

    searchQuery() {
      this.loadData(1);
      this.loadData2(1);
    },

    searchReset() {
      this.faultTime = []
      this.queryParam = {}
      this.loadData(1);
      this.loadData2(1);
    },

    loadData(arg) {
      this.loading = true;
      getAction(this.url.list, this.queryParam).then((res) => {
        if (res.success) {
          this.barData = res.result.records || res.result;
        } else {
          this.$message.warning(res.message)
        }
      }).finally(() => {
        this.loading = false
      })
    },

    loadData2(arg) {
      this.loading = true;
      getAction(this.url.list2, this.queryParam).then((res) => {
        if (res.success) {
          this.defectInfo = res.result.records || res.result;
        } else {
          this.$message.warning(res.message)
        }
      }).finally(() => {
        this.loading = false
      })
    },

  }
}
</script>
<style scoped>
@import '~@assets/less/common.less';
</style>